<?php
/**
 * Main plugin file. Finally, use widgets to maintain and customize your 404 Error and Search Not Found pages in Genesis Framework and Child Themes.
 *
 * @package   Genesis Widgetized Not Found & 404
 * @author    David Decker
 * @link      http://twitter.com/#!/deckerweb
 * @copyright Copyright 2012, David Decker - DECKERWEB
 *
 * Plugin Name: Genesis Widgetized Not Found & 404
 * Plugin URI: http://genesisthemes.de/en/wp-plugins/genesis-widgetized-notfound/
 * Description: Finally, use widgets to maintain and customize your 404 Error and Search Not Found pages in Genesis Framework and Child Themes.
 * Version: 1.0.1
 * Author: David Decker - DECKERWEB
 * Author URI: http://deckerweb.de/
 * License: GPLv2
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: genesis-widgetized-notfound
 * Domain Path: /languages/
 */

/**
 * Setting constants & some variables
 *
 * @since 1.0
 */
/** Set plugin version */
define( 'GWNF_VERSION', '1.0.1' );

/** Plugin base directory */
define( 'GWNF_PLUGIN_BASEDIR', dirname( plugin_basename( __FILE__ ) ) );


add_action( 'init', 'ddw_gwnf_init', 1 );
/**
 * Load the text domain for translation of the plugin
 * 
 * @since 1.0
 */
function ddw_gwnf_init() {

	/** First look in WordPress' "languages" folder = custom & update-secure! */
	load_plugin_textdomain( 'genesis-widgetized-notfound', false, GWNF_PLUGIN_BASEDIR . '/../../languages/genesis-widgetized-notfound/' );

	/** Then look in plugin's "languages" folder = default */
	load_plugin_textdomain( 'genesis-widgetized-notfound', false, GWNF_PLUGIN_BASEDIR . '/languages/' );

}  // end of function ddw_gwnf_init


register_activation_hook( __FILE__, 'ddw_gwnf_activation_check' );
/**
 * Checks for activated Genesis Framework before allowing plugin to activate
 *
 * @author Nathan Rice
 *
 * @since 1.0
 */
function ddw_gwnf_activation_check() {

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( basename( get_template_directory() ) != 'genesis' ) {

		/** If no Genesis, deactivate ourself */
		deactivate_plugins( plugin_basename( __FILE__ ) );

		/** Deactivation message */
		wp_die( sprintf( __( 'Sorry, you can&rsquo;t activate unless you have installed the %1$sGenesis Framework%2$s', 'genesis-widgetized-notfound' ), '<a href="http://deckerweb.de/go/genesis/" target="_new">', '</a>' ) );

	}  // end-if Genesis check

}  // end of function ddw_gwnf_activation_check


add_filter( 'plugin_action_links_' . plugin_basename(__FILE__) , 'ddw_gwnf_widgets_page_link' );
/**
 * Add "Widgets Page" link to plugin page
 *
 * @since 1.0
 *
 * @param  $gwnf_links
 * @param  $gwnf_widgets_link
 * @return strings widgets link
 */
function ddw_gwnf_widgets_page_link( $gwnf_links ) {

	$gwnf_widgets_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'widgets.php' ) , __( 'Go to the Widgets settings page', 'genesis-widgetized-notfound' ) , __( 'Widgets', 'genesis-widgetized-notfound' ) );
	
	array_unshift( $gwnf_links, $gwnf_widgets_link );

	return $gwnf_links;

}  // end of function ddw_gwnf_widgets_page_link


add_filter( 'plugin_row_meta', 'ddw_gwnf_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0
 *
 * @param  $gwnf_links
 * @param  $gwnf_file
 * @return strings plugin links
 */
function ddw_gwnf_plugin_links( $gwnf_links, $gwnf_file ) {

	if ( ! current_user_can( 'install_plugins' ) )
		return $gwnf_links;

	if ( $gwnf_file == GWNF_PLUGIN_BASEDIR . '/genesis-widgetized-notfound.php' ) {
		$gwnf_links[] = '<a href="http://wordpress.org/extend/plugins/genesis-widgetized-notfound/faq/" target="_new" title="' . __( 'FAQ', 'genesis-widgetized-notfound' ) . '">' . __( 'FAQ', 'genesis-widgetized-notfound' ) . '</a>';
		$gwnf_links[] = '<a href="http://wordpress.org/tags/genesis-widgetized-notfound?forum_id=10" target="_new" title="' . __( 'Support', 'genesis-widgetized-notfound' ) . '">' . __( 'Support', 'genesis-widgetized-notfound' ) . '</a>';
		$gwnf_links[] = '<a href="' . __( 'http://genesisthemes.de/en/donate/', 'genesis-widgetized-notfound' ) . '" target="_new" title="' . __( 'Donate', 'genesis-widgetized-notfound' ) . '">' . __( 'Donate', 'genesis-widgetized-notfound' ) . '</a>';
	}

	return $gwnf_links;

}  // end of function ddw_gwnf_plugin_links


add_action( 'init', 'ddw_gwnf_setup' );
/**
 * Setup: Register Widget Areas (Note: Has to be early on the "init" hook in order to display translations!)
 *
 * @since 1.0
 */
function ddw_gwnf_setup() {

	/** Set filter for "404 Error Page" widget title */
	$gwnf_404_widget_title = apply_filters( 'gwnf_filter_404_widget_title', __( '404 Error Page', 'genesis-widgetized-notfound' ) );

	/** Set filter for "404 Error Page" widget description */
	$gwnf_404_widget_description = apply_filters( 'gwnf_filter_404_widget_description', __( 'This is the widget area of the 404 Not Found Error Page.', 'genesis-widgetized-notfound' ) );

	/** Register the "404 Error Page" widget area */
	register_sidebar(
		array(
			'id' => 'gwnf-404-widget',
			'name' => $gwnf_404_widget_title,
			'description' => $gwnf_404_widget_description,
			'before_widget' => '<div id="%1$s" class="gwnf-404 widget-area">',
			'after_widget' => '</div>',
		)
	);

	/** Set filter for "Search Not Found" widget title */
	$gwnf_notfound_widget_title = apply_filters( 'gwnf_filter_notfound_widget_title', __( 'Search Not Found', 'genesis-widgetized-notfound' ) );

	/** Set filter for "Search Not Found" widget description */
	$gwnf_notfound_widget_description = apply_filters( 'gwnf_filter_notfound_widget_description', __( 'This is the widget area of the search not found content section.', 'genesis-widgetized-notfound' ) );

	/** Register the "Search Not Found" widget area */
	register_sidebar(
		array(
			'id' => 'gwnf-notfound-widget',
			'name' => $gwnf_notfound_widget_title,
			'description' => $gwnf_notfound_widget_description,
			'before_widget' => '<div id="%1$s" class="gwnf-notfound widget-area">',
			'after_widget' => '</div>',
		)
	);

}  // end of function ddw_gwnf_setup


add_action( 'genesis_meta', 'gwnf_404_content' );
/**
 * Add the new widgetized 404 Error Page content
 *
 * @since 1.0
 */
function gwnf_404_content() {

	if ( is_404() && is_active_sidebar( 'gwnf-404-widget' ) ) {

		remove_action( 'genesis_loop', 'genesis_404' );
		add_action( 'genesis_loop', 'gwnf_display_404_widget' );

	}  // end-if

}  // end of function gwnf_404_content


/**
 * Display the "404 Error Page" widget
 *
 * @since 1.0
 */
function gwnf_display_404_widget() {

	echo '<div id="gwnf-404-area">';
	dynamic_sidebar( 'gwnf-404-widget' );
	echo '</div><!-- end #gwnf-404-area -->';

}  // end of function gwnf_display_404_widget


add_filter( 'genesis_noposts_text', 'gwnf_nocontent_status' );
/**
 * Modify the no content text
 * Hook in the "Search Not Found" widget
 *
 * @since 1.0
 */
function gwnf_nocontent_status() {

	/** Set filter for default "Search Not Found" message */
	$gwnf_notfound_default = apply_filters( 'gwnf_filter_notfound_default', __( 'Sorry, no content matched your criteria. Try a different search?', 'genesis-widgetized-notfound' ) );

	/** Display active widget area "Search Not Found" */
	if ( is_active_sidebar( 'gwnf-notfound-widget' ) ) {

		echo '<div id="gwnf-notfound-area">';
		dynamic_sidebar( 'gwnf-notfound-widget' );
		echo '</div><!-- end #gwnf-notfound-area -->';
	}

	/** If inactive display default message */
	else {
		echo '<div class="gwnf-notfound-default">' . $gwnf_notfound_default . '</div>';

	}  // end if-else

}  // end of function gwnf_nocontent_status


add_action( 'wp_enqueue_scripts', 'ddw_gwnf_styles' );
/**
 * Enqueue a few additional CSS rules
 * for enhanced compatibility with Genesis Child Themes
 * 
 * @since 1.0
 */
function ddw_gwnf_styles() {

	if ( is_404() || is_search() ) {
		wp_enqueue_style( 'genesis-widgetized-notfound', plugins_url( 'css/gwnf-styles.css', __FILE__ ), false, GWNF_VERSION, 'all' );

	}  // end-if

}  // end of function ddw_gwnf_styles
